Cmdselect

Enum Cmdselect 

#[repr(u8)]
pub enum Cmdselect {
Show 13 variants Er = 2, Wp = 4, Ear = 5, Wap = 6, Sf = 10, Wl = 15, Lr = 64, Ur = 65, Sprm = 66, Cprm = 67, Pbc = 68, Ssb = 69, Invall = 70,
}
Command

Value on reset: 0

Variants



Er = 2

2: Erase Row - Erases the row addressed by the ADDR register.



Wp = 4

4: Write Page - Writes the contents of the page buffer to the page addressed by the ADDR register.



Ear = 5

5: Erase Auxiliary Row - Erases the auxiliary row addressed by the ADDR register. This command can be given only when the security bit is not set and only to the user configuration row.



Wap = 6

6: Write Auxiliary Page - Writes the contents of the page buffer to the page addressed by the ADDR register. This command can be given only when the security bit is not set and only to the user configuration row.



Sf = 10

10: Security Flow Command



Wl = 15

15: Write lockbits



Lr = 64

64: Lock Region - Locks the region containing the address location in the ADDR register.



Ur = 65

65: Unlock Region - Unlocks the region containing the address location in the ADDR register.



Sprm = 66

66: Sets the power reduction mode.



Cprm = 67

67: Clears the power reduction mode.



Pbc = 68

68: Page Buffer Clear - Clears the page buffer.



Ssb = 69

69: Set Security Bit - Sets the security bit by writing 0x00 to the first byte in the lockbit row.



Invall = 70

70: Invalidates all cache lines.